<div align="center">
  <img width=500px" src="https://framagit.org/gabylaunay/pyDSA_core/raw/master/branding/pyDSA_logo_python_text.svg"><br><br>
</div>

# PyDSA_core: python3 package for drop shape analysis.

## Features

PyDSA_core allow to import videos and images of droplets and to get their properties, including

  - Drop edges positions
  - Contact angles
  - Contact angle hysteresis
  - Radius
  - Volume
  - Triple point positions (for SLIPS surfaces)
  - ...

A Graphical interface is also available [here](https://framagit.org/gabylaunay/pyDSA_gui).

A tutorial is available [here](https://gabylaunay.github.io/Python-cookbook/).

## Dependencies

pyDSA_core relies on matplotlib, numpy, scipy, IMTreatment and OpenCV.

## Installation

``pip install pydsa_core``

To update pyDSA_core, use:

``pip install -U pydsa_core``

## Citing this software

If PyDSA_core have been usefull for you, please consider citing it:
```
Launay G. PyDSA: Drop shape analysis in Python, 2018-, https://framagit.org/gabylaunay/pyDSA_core [Online; accessed <today>].
```

bibtex entry:
``` bibtex
@Misc{launay_pydsa_2018,
  author =    {Gaby Launay},
  title =     {{PyDSA}: Drop shape analysis in {Python}},
  year =      {2018--},
  url = "https://framagit.org/gabylaunay/pyDSA_core",
  note = {[Online; accessed <today>]}
}

```
